{% load i18n %} {% load history_sidebar %}
{{ log.timestamp|date:"SHORT_DATETIME_FORMAT" }}
{% if log.person %}
{% if log.is_orga_action %} {% else %} {% endif %} {% include "orga/includes/user_name.html" with user=log.person lightbox=True %}
{% endif %} {% if log.display_object %}
{{ log.display_object|safe }}
{% endif %}
{{ log.display }}
{% if is_htmx_request %}
{% translate "Permalink" %}
{% endif %}
{% if log.changes %}

### {% translate "Changes" %}

{% translate "Field" %} | {% translate "Before" %} | {% translate "After" %}
--- | --- | ---
{% for field, change in log.changes.items %} {% change_row field change log %} {% endfor %}

{% endif %}